@@ -19,7 +19,8 @@ from sequana_pipetools.misc import Colors, print_version, print_newest_version
 
 
 __all__ = ["GeneralOptions", "SlurmOptions", "SnakemakeOptions",
-    "CutadaptOptions", "KrakenOptions", "InputOptions", "FeatureCountsOptions"]
+            "TrimmingOptions", "KrakenOptions", "InputOptions", 
+            "FeatureCountsOptions"]
 
 
 def init_pipeline(NAME):
@@ -200,7 +201,73 @@ class KrakenOptions():
                 performed as explained in online sequana documentation""")
 
 
-class CutadaptOptions():
+class TrimmingOptions():
+    description = """
+    This section is dedicated to reads trimming and filtering and adapter
+    trimming. We currently provide supports for Cutadapt and FastP tools.
+
+    This section uniformizes the options for such tools
+
+
+    """
+    def __init__(self, group_name="section_trimming"):
+        self.group_name = group_name
+
+    def add_options(self, parser):
+
+        group = parser.add_argument_group(self.group_name, self.description)
+
+
+
+        group.add_argument("--software-choice", dest="trimming_software_choice",
+            default="fastp", choices=["cutadapt", "atropos", "fastp"],
+            help="""additional options understood by cutadapt""")
+
+        group.add_argument("--disable-trimming", action="store_true",
+            default=False,
+            help="If provided, disable trimming ")
+
+
+        group.add_argument("--trimming-adapter-read1", dest="trimming_adapter_read1",
+            default="", help="""fastp auto-detects adapters. You may specify the
+adapter sequence specificically for fastp or cutadapt/atropos with option for
+read1""")
+
+        group.add_argument("--trimming-adapter-read2", dest="trimming_adapter_read2",
+            default="", help="""fastp auto-detects adapters. You may specify the
+adapter sequence specificically for fastp or cutadapt/atropos with option for
+read1""")
+
+        group.add_argument("--trimming-minimum-length", 
+            default=20, help="""minimum number of bases required; read discarded
+otherwise. For cutadapt, default is 20 and for fastp, 15. We use 20 for both by
+default.""")
+
+        def quality(x):
+            x = int(x)
+            if x < 0:
+                raise argparse.ArgumentTypeError("quality must be positive")
+            return x
+        group.add_argument("--trimming-quality", dest="trimming_quality",
+            default=-1, type=quality,
+            help="""Trimming quality parameter depends on the algorithm used by 
+the software behind the scene an may vary greatly; consequently, not provide 
+a default value. Cutadapt uses 30 by default, fastp uses 15 by default. If
+unset, the rnaseq pipeline set the default to 30 for cutadapt and 15 for fastp""")
+
+        # Cutadapt specific
+        group.add_argument("--trimming-cutadapt-mode", dest="trimming_cutadapt_mode",
+            default="b", choices=["g", "a", "b"],
+            help="""Mode used to remove adapters. g for 5', a for 3', b for both
+                5'/3' as defined in cutadapt documentation""")
+        group.add_argument("--trimming-cutadapt-options", dest="trimming_cutadapt_options",
+            default=" -O 6 --trim-n",
+            help="""additional options understood by cutadapt. Here, we trim the
+Ns; -O 6 is the minimum overlap length between read and adapter for an adapter
+to be found""")
+
+
+class CutadaptOptions(): #pragma: no cover
     description = """
     This section allows you to trim bases (--cutadapt-quality) with poor
     quality and/or remove adapters.
@@ -226,6 +293,7 @@ class CutadaptOptions():
 
     def __init__(self, group_name="section_cutadapt"):
         self.group_name = group_name
+        print("CutadaptOptions is deprecated. Will be removed in future versions. Use TrimmingOptions instead")
 
     def add_options(self, parser):
 
